@@ -126,6 +126,7 @@ if TYPE_CHECKING:
         params as params,
         radar as radar,
         reporting as reporting,
+        reserve as reserve,
         sigma as sigma,
         tax as tax,
         terminal as terminal,
@@ -555,6 +556,7 @@ _import_map = {
     "params": ("stripe.params", True),
     "radar": ("stripe.radar", True),
     "reporting": ("stripe.reporting", True),
+    "reserve": ("stripe.reserve", True),
     "sigma": ("stripe.sigma", True),
     "tax": ("stripe.tax", True),
     "terminal": ("stripe.terminal", True),
