@@ -220,7 +220,7 @@ class TestAPIRequestor(object):
 
     def test_dictionary_list_encoding(self):
         params = {"foo": {"0": {"bar": "bat"}}}
-        encoded = list(_api_encode(params, "V1"))
+        encoded = list(_api_encode(params))
         key, value = encoded[0]
 
         assert key == "foo[0][bar]"
@@ -237,7 +237,7 @@ class TestAPIRequestor(object):
                 ]
             )
         }
-        encoded = list(_api_encode(params, "V1"))
+        encoded = list(_api_encode(params))
 
         assert encoded[0][0] == "ordered[one]"
         assert encoded[1][0] == "ordered[two]"
@@ -572,7 +572,9 @@ class TestAPIRequestor(object):
 
     def test_uses_instance_key(self, requestor, http_client_mock):
         key = "fookey"
-        requestor = requestor._replace_options(RequestOptions(api_key=key))
+        requestor = requestor._new_requestor_with_options(
+            RequestOptions(api_key=key)
+        )
 
         http_client_mock.stub_request(
             "get", path=self.v1_path, rbody="{}", rcode=200
@@ -585,7 +587,7 @@ class TestAPIRequestor(object):
 
     def test_uses_instance_account(self, requestor, http_client_mock):
         account = "acct_foo"
-        requestor = requestor._replace_options(
+        requestor = requestor._new_requestor_with_options(
             RequestOptions(stripe_account=account)
         )
 
@@ -610,7 +612,7 @@ class TestAPIRequestor(object):
         in the generated fetch_related_object doesn't actually send the null header
         """
         account = None
-        requestor = requestor._replace_options(
+        requestor = requestor._new_requestor_with_options(
             RequestOptions(stripe_account=account)
         )
 
